@@ -25,6 +25,8 @@
 #ifndef LIBFAUSTCOMMON_C_H
 #define LIBFAUSTCOMMON_C_H
 
+#include "faust/export.h"
+
 /*!
  \addtogroup boxc C interface for the Box API.
  @{
@@ -52,7 +54,6 @@ enum SOperator { kAdd, kSub, kMul, kDiv, kRem, kLsh, kARsh, kLRsh, kGT, kLT, kGE
 #ifndef LIBFAUSTBOX_C_H
 #define LIBFAUSTBOX_C_H
 
-
 #ifdef __cplusplus
 extern "C"
 {
@@ -61,13 +62,49 @@ extern "C"
     /**
      * Create global compilation context, has to be done first.
      */
-    extern "C" void createLibContext();
+    LIBFAUST_API void createLibContext();
     
     /**
      * Destroy global compilation context, has to be done last.
      */
-    extern "C" void destroyLibContext();
-    
+    LIBFAUST_API void destroyLibContext();
+
+    /**
+     * Check if a box is nil.
+     *
+     * @param b - the box
+     *
+     * @return true if the box is nil, otherwise false.
+     */
+    LIBFAUST_API bool CisNil(Box b);
+
+    /**
+     * Convert a box (such as the label of a UI) to a string.
+     *
+     * @param b - the box to convert
+     *
+     * @return a string representation of a box.
+     */
+    LIBFAUST_API const char* Ctree2str(Box b);
+
+    /**
+     * If t has a node of type int, return it. Otherwise error
+     *
+     * @param b - the box to convert
+     *
+     * @return the int value of the box.
+     */
+    LIBFAUST_API int Ctree2int(Box b);
+
+    /**
+     * Return the xtended type of a box.
+     *
+     * @param b - the box whose xtended type to return
+     *
+     * @return a pointer to xtended type if it exists, otherwise nullptr.
+     */
+    LIBFAUST_API void* CgetUserData(Box b);
+
     /**
      * Constant integer : for all t, x(t) = n.
      *
@@ -76,7 +113,7 @@ extern "C"
      * @return the integer box.
      */
     
-    Box CboxInt(int n);
+    LIBFAUST_API Box CboxInt(int n);
     
     /**
      * Constant real : for all t, x(t) = n.
@@ -85,28 +122,28 @@ extern "C"
      *
      * @return the float/double box.
      */
-    Box CboxReal(double n);
+    LIBFAUST_API Box CboxReal(double n);
     
     /**
      * The identity box, copy its input to its output.
      *
      * @return the identity box.
      */
-    Box CboxWire();
+    LIBFAUST_API Box CboxWire();
     
     /**
      * The cut box, to "stop"/terminate a signal.
      *
      * @return the cut box.
      */
-    Box CboxCut();
+    LIBFAUST_API Box CboxCut();
     
     /**
      * The sequential composition of two blocks (e.g., A:B) expects: outputs(A)=inputs(B)
      *
      * @return the seq box.
      */
-    Box CboxSeq(Box x, Box y);
+    LIBFAUST_API Box CboxSeq(Box x, Box y);
     
     /**
      * The parallel composition of two blocks (e.g., A,B).
@@ -114,13 +151,13 @@ extern "C"
      *
      * @return the par box.
      */
-    Box CboxPar(Box x, Box y);
+    LIBFAUST_API Box CboxPar(Box x, Box y);
     
-    Box CboxPar3(Box x, Box y, Box z);
+    LIBFAUST_API Box CboxPar3(Box x, Box y, Box z);
     
-    Box CboxPar4(Box a, Box b, Box c, Box d);
+    LIBFAUST_API Box CboxPar4(Box a, Box b, Box c, Box d);
     
-    Box CboxPar5(Box a, Box b, Box c, Box d, Box e);
+    LIBFAUST_API Box CboxPar5(Box a, Box b, Box c, Box d, Box e);
     
     /**
      * The split composition (e.g., A<:B) operator is used to distribute
@@ -131,7 +168,7 @@ extern "C"
      *
      * @return the split box.
      */
-    Box CboxSplit(Box x, Box y);
+    LIBFAUST_API Box CboxSplit(Box x, Box y);
     
     /**
      * The merge composition (e.g., A:>B) is the dual of the split composition.
@@ -140,7 +177,7 @@ extern "C"
      *
      * @return the merge box.
      */
-    Box CboxMerge(Box x, Box y);
+    LIBFAUST_API Box CboxMerge(Box x, Box y);
     
     /**
      * The recursive composition (e.g., A~B) is used to create cycles in the block-diagram
@@ -149,7 +186,7 @@ extern "C"
      *
      * @return the rec box.
      */
-    Box CboxRec(Box x, Box y);
+    LIBFAUST_API Box CboxRec(Box x, Box y);
     
     /**
      * The route primitive facilitates the routing of signals in Faust.
@@ -161,14 +198,14 @@ extern "C"
      
      * @return the route box.
      */
-    Box CboxRoute(Box n, Box m, Box r);
+    LIBFAUST_API Box CboxRoute(Box n, Box m, Box r);
     
     /**
      * Create a delayed box.
      *
      * @return the delayed box.
      */
-    Box CboxDelay();
+    LIBFAUST_API Box CboxDelay();
     
     /**
      * Create a delayed box.
@@ -178,14 +215,14 @@ extern "C"
      
      * @return the delayed box.
      */
-    Box CboxDelayAux(Box s, Box del);
+    LIBFAUST_API Box CboxDelayAux(Box b, Box del);
     
     /**
      * Create a casted box.
      *
      * @return the casted box.
      */
-    Box CboxIntCast();
+    LIBFAUST_API Box CboxIntCast();
     
     /**
      * Create a casted box.
@@ -194,14 +231,14 @@ extern "C"
      *
      * @return the casted box.
      */
-    Box CboxIntCastAux(Box s);
+    LIBFAUST_API Box CboxIntCastAux(Box b);
     
     /**
      * Create a casted box.
      *
      * @return the casted box.
      */
-    Box CboxFloatCast();
+    LIBFAUST_API Box CboxFloatCast();
     
     /**
      * Create a casted box.
@@ -210,14 +247,14 @@ extern "C"
      *
      * @return the casted box.
      */
-    Box CboxFloatCastAux(Box s);
+    LIBFAUST_API Box CboxFloatCastAux(Box b);
     
     /**
      * Create a read only table.
      *
      * @return the table box.
      */
-    Box CboxReadOnlyTable();
+    LIBFAUST_API Box CboxReadOnlyTable();
     
     /**
      * Create a read only table.
@@ -228,14 +265,14 @@ extern "C"
      *
      * @return the table box.
      */
-    Box CboxReadOnlyTableAux(Box n, Box init, Box ridx);
+    LIBFAUST_API Box CboxReadOnlyTableAux(Box n, Box init, Box ridx);
     
     /**
      * Create a read/write table.
      *
      * @return the table box.
      */
-    Box CboxWriteReadTable();
+    LIBFAUST_API Box CboxWriteReadTable();
     
     /**
      * Create a read/write table.
@@ -248,7 +285,7 @@ extern "C"
      *
      * @return the table box.
      */
-    Box CboxWriteReadTableAux(Box n, Box init, Box widx, Box wsig, Box ridx);
+    LIBFAUST_API Box CboxWriteReadTableAux(Box n, Box init, Box widx, Box wsig, Box ridx);
     
     /**
      * Create a waveform.
@@ -257,7 +294,7 @@ extern "C"
      *
      * @return the waveform box.
      */
-    Box CboxWaveform(Box* wf);
+    LIBFAUST_API Box CboxWaveform(Box* wf);
     
     /**
      * Create a soundfile block.
@@ -267,7 +304,7 @@ extern "C"
      *
      * @return the soundfile box.
      */
-    Box CboxSoundfile(const char* label, Box chan);
+    LIBFAUST_API Box CboxSoundfile(const char* label, Box chan);
     
     /**
      * Create a soundfile block.
@@ -286,7 +323,7 @@ extern "C"
      *
      * @return the selected box depending of the selector value at each time t.
      */
-    Box CboxSelect2();
+    LIBFAUST_API Box CboxSelect2();
     
     /**
      * Create a selector between two boxes.
@@ -297,14 +334,14 @@ extern "C"
      *
      * @return the selected box depending of the selector value at each time t.
      */
-    Box CboxSelect2Aux(Box selector, Box s1, Box s2);
+    LIBFAUST_API Box CboxSelect2Aux(Box selector, Box b1, Box b2);
     
     /**
      * Create a selector between three boxes.
      *
      * @return the selected box depending of the selector value at each time t.
      */
-    Box CboxSelect3();
+    LIBFAUST_API Box CboxSelect3();
     
     /**
      * Create a selector between three boxes.
@@ -312,11 +349,11 @@ extern "C"
      * @param selector - when 0 at time t returns s1[t], when 1 at time t returns s2[t], otherwise returns s3[t]
      * @param s1 - first box to be selected
      * @param s2 - second box to be selected
-     * @param s3 - third signal to be selected
+     * @param s3 - third box to be selected
      *
      * @return the selected box depending of the selector value at each time t.
      */
-    Box CboxSelect3Aux(Box selector, Box s1, Box s2, Box s3);
+    LIBFAUST_API Box CboxSelect3Aux(Box selector, Box b1, Box b2, Box b3);
     
     /**
      * Create a foreign constant box.
@@ -327,7 +364,7 @@ extern "C"
      *
      * @return the foreign constant box.
      */
-    Box CboxFConst(SType type, const char* name, const char* file);
+    LIBFAUST_API Box CboxFConst(SType type, const char* name, const char* file);
     
     /**
      * Create a foreign variable box.
@@ -338,7 +375,7 @@ extern "C"
      *
      * @return the foreign variable box.
      */
-    Box CboxFVar(SType type, const char* name, const char* file);
+    LIBFAUST_API Box CboxFVar(SType type, const char* name, const char* file);
     
     /**
      * Generic binary mathematical functions.
@@ -347,102 +384,102 @@ extern "C"
      *
      * @return the result box of op(x,y).
      */
-    Box CboxBinOp(SOperator op);
+    LIBFAUST_API Box CboxBinOp(SOperator op);
     
-    Box CboxBinOpAux(SOperator op, Box b1, Box b2);
+    LIBFAUST_API Box CboxBinOpAux(SOperator op, Box b1, Box b2);
     
     /**
      * Specific binary mathematical functions.
      *
      * @return the result box.
      */
-    Box CboxAdd();
-    Box CboxAddAux(Box b1, Box b2);
-    Box CboxSub();
-    Box CboxSubAux(Box b1, Box b2);
-    Box CboxMul();
-    Box CboxMulAux(Box b1, Box b2);
-    Box CboxDiv();
-    Box CboxDivAux(Box b1, Box b2);
-    Box CboxRem();
-    Box CboxRemAux(Box b1, Box b2);
+    LIBFAUST_API Box CboxAdd();
+    LIBFAUST_API Box CboxAddAux(Box b1, Box b2);
+    LIBFAUST_API Box CboxSub();
+    LIBFAUST_API Box CboxSubAux(Box b1, Box b2);
+    LIBFAUST_API Box CboxMul();
+    LIBFAUST_API Box CboxMulAux(Box b1, Box b2);
+    LIBFAUST_API Box CboxDiv();
+    LIBFAUST_API Box CboxDivAux(Box b1, Box b2);
+    LIBFAUST_API Box CboxRem();
+    LIBFAUST_API Box CboxRemAux(Box b1, Box b2);
     
-    Box CboxLeftShift();
-    Box CboxLeftShiftAux(Box b1, Box b2);
-    Box CboxLRightShift();
-    Box CboxLRightShiftAux(Box b1, Box b2);
-    Box CboxARightShift();
-    Box CboxARightShiftAux(Box b1, Box b2);
+    LIBFAUST_API Box CboxLeftShift();
+    LIBFAUST_API Box CboxLeftShiftAux(Box b1, Box b2);
+    LIBFAUST_API Box CboxLRightShift();
+    LIBFAUST_API Box CboxLRightShiftAux(Box b1, Box b2);
+    LIBFAUST_API Box CboxARightShift();
+    LIBFAUST_API Box CboxARightShiftAux(Box b1, Box b2);
     
-    Box CboxGT();
-    Box CboxGTAux(Box b1, Box b2);
-    Box CboxLT();
-    Box CboxLTAux(Box b1, Box b2);
-    Box CboxGE();
-    Box CboxGEAux(Box b1, Box b2);
-    Box CboxLE();
-    Box CboxLEAux(Box b1, Box b2);
-    Box CboxEQ();
-    Box CboxEQAux(Box b1, Box b2);
-    Box CboxNE();
-    Box CboxNEAux(Box b1, Box b2);
+    LIBFAUST_API Box CboxGT();
+    LIBFAUST_API Box CboxGTAux(Box b1, Box b2);
+    LIBFAUST_API Box CboxLT();
+    LIBFAUST_API Box CboxLTAux(Box b1, Box b2);
+    LIBFAUST_API Box CboxGE();
+    LIBFAUST_API Box CboxGEAux(Box b1, Box b2);
+    LIBFAUST_API Box CboxLE();
+    LIBFAUST_API Box CboxLEAux(Box b1, Box b2);
+    LIBFAUST_API Box CboxEQ();
+    LIBFAUST_API Box CboxEQAux(Box b1, Box b2);
+    LIBFAUST_API Box CboxNE();
+    LIBFAUST_API Box CboxNEAux(Box b1, Box b2);
     
-    Box CboxAND();
-    Box CboxANDAux(Box b1, Box b2);
-    Box CboxOR();
-    Box CboxORAux(Box b1, Box b2);
-    Box CboxXOR();
-    Box CboxXORAux(Box b1, Box b2);
+    LIBFAUST_API Box CboxAND();
+    LIBFAUST_API Box CboxANDAux(Box b1, Box b2);
+    LIBFAUST_API Box CboxOR();
+    LIBFAUST_API Box CboxORAux(Box b1, Box b2);
+    LIBFAUST_API Box CboxXOR();
+    LIBFAUST_API Box CboxXORAux(Box b1, Box b2);
     
     /**
      * Extended unary mathematical functions.
      */
-    Box CboxAbs();
-    Box CboxAbsAux(Box x);
-    Box CboxAcos();
-    Box CboxAcosAux(Box x);
-    Box CboxTan();
-    Box CboxTanAux(Box x);
-    Box CboxSqrt();
-    Box CboxSqrtAux(Box x);
-    Box CboxSin();
-    Box CboxSinAux(Box x);
-    Box CboxRint();
-    Box CboxRintAux(Box x);
-    Box CboxLog();
-    Box CboxLogAux(Box x);
-    Box CboxLog10();
-    Box CboxLog10Aux(Box x);
-    Box CboxFloor();
-    Box CboxFloorAux(Box x);
-    Box CboxExp();
-    Box CboxExpAux(Box x);
-    Box CboxExp10();
-    Box CboxExp10Aux(Box x);
-    Box CboxCos();
-    Box CboxCosAux(Box x);
-    Box CboxCeil();
-    Box CboxCeilAux(Box x);
-    Box CboxAtan();
-    Box CboxAtanAux(Box x);
-    Box CboxAsin();
-    Box CboxAsinAux(Box x);
+    LIBFAUST_API Box CboxAbs();
+    LIBFAUST_API Box CboxAbsAux(Box x);
+    LIBFAUST_API Box CboxAcos();
+    LIBFAUST_API Box CboxAcosAux(Box x);
+    LIBFAUST_API Box CboxTan();
+    LIBFAUST_API Box CboxTanAux(Box x);
+    LIBFAUST_API Box CboxSqrt();
+    LIBFAUST_API Box CboxSqrtAux(Box x);
+    LIBFAUST_API Box CboxSin();
+    LIBFAUST_API Box CboxSinAux(Box x);
+    LIBFAUST_API Box CboxRint();
+    LIBFAUST_API Box CboxRintAux(Box x);
+    LIBFAUST_API Box CboxLog();
+    LIBFAUST_API Box CboxLogAux(Box x);
+    LIBFAUST_API Box CboxLog10();
+    LIBFAUST_API Box CboxLog10Aux(Box x);
+    LIBFAUST_API Box CboxFloor();
+    LIBFAUST_API Box CboxFloorAux(Box x);
+    LIBFAUST_API Box CboxExp();
+    LIBFAUST_API Box CboxExpAux(Box x);
+    LIBFAUST_API Box CboxExp10();
+    LIBFAUST_API Box CboxExp10Aux(Box x);
+    LIBFAUST_API Box CboxCos();
+    LIBFAUST_API Box CboxCosAux(Box x);
+    LIBFAUST_API Box CboxCeil();
+    LIBFAUST_API Box CboxCeilAux(Box x);
+    LIBFAUST_API Box CboxAtan();
+    LIBFAUST_API Box CboxAtanAux(Box x);
+    LIBFAUST_API Box CboxAsin();
+    LIBFAUST_API Box CboxAsinAux(Box x);
     
     /**
      * Extended binary mathematical functions.
      */
-    Box CboxRemainder();
-    Box CboxRemainderAux(Box b1, Box b2);
-    Box CboxPow();
-    Box CboxPowAux(Box b1, Box b2);
-    Box CboxMin();
-    Box CboxMinAux(Box b1, Box b2);
-    Box CboxMax();
-    Box CboxMaxAux(Box b1, Box b2);
-    Box CboxFmod();
-    Box CboxFmodAux(Box b1, Box b2);
-    Box CboxAtan2();
-    Box CboxAtan2Aux(Box b1, Box b2);
+    LIBFAUST_API Box CboxRemainder();
+    LIBFAUST_API Box CboxRemainderAux(Box b1, Box b2);
+    LIBFAUST_API Box CboxPow();
+    LIBFAUST_API Box CboxPowAux(Box b1, Box b2);
+    LIBFAUST_API Box CboxMin();
+    LIBFAUST_API Box CboxMinAux(Box b1, Box b2);
+    LIBFAUST_API Box CboxMax();
+    LIBFAUST_API Box CboxMaxAux(Box b1, Box b2);
+    LIBFAUST_API Box CboxFmod();
+    LIBFAUST_API Box CboxFmodAux(Box b1, Box b2);
+    LIBFAUST_API Box CboxAtan2();
+    LIBFAUST_API Box CboxAtan2Aux(Box b1, Box b2);
     
     /**
      * Create a button box.
@@ -451,7 +488,7 @@ extern "C"
      *
      * @return the button box.
      */
-    Box CboxButton(const char* label);
+    LIBFAUST_API Box CboxButton(const char* label);
     
     /**
      * Create a checkbox box.
@@ -460,7 +497,7 @@ extern "C"
      *
      * @return the checkbox box.
      */
-    Box CboxCheckbox(const char* label);
+    LIBFAUST_API Box CboxCheckbox(const char* label);
     
     /**
      * Create a vertical slider box.
@@ -473,7 +510,7 @@ extern "C"
      *
      * @return the vertical slider box.
      */
-    Box CboxVSlider(const char* label, Box init, Box min, Box max, Box step);
+    LIBFAUST_API Box CboxVSlider(const char* label, Box init, Box min, Box max, Box step);
     
     /**
      * Create an horizontal slider box.
@@ -486,7 +523,7 @@ extern "C"
      *
      * @return the horizontal slider box.
      */
-    Box CboxHSlider(const char* label, Box init, Box min, Box max, Box step);
+    LIBFAUST_API Box CboxHSlider(const char* label, Box init, Box min, Box max, Box step);
     
     /**
      * Create a num entry box.
@@ -499,7 +536,7 @@ extern "C"
      *
      * @return the num entry box.
      */
-    Box CboxNumEntry(const char* label, Box init, Box min, Box max, Box step);
+    LIBFAUST_API Box CboxNumEntry(const char* label, Box init, Box min, Box max, Box step);
     
     /**
      * Create a vertical bargraph box.
@@ -510,7 +547,7 @@ extern "C"
      *
      * @return the vertical bargraph box.
      */
-    Box CboxVBargraph(const char* label, Box min, Box max);
+    LIBFAUST_API Box CboxVBargraph(const char* label, Box min, Box max);
     
     /**
      * Create a vertical bargraph box.
@@ -522,7 +559,7 @@ extern "C"
      *
      * @return the vertical bargraph box.
      */
-    Box CboxVBargraphAux(const char* label, Box min, Box max, Box x);
+    LIBFAUST_API Box CboxVBargraphAux(const char* label, Box min, Box max, Box x);
     
     /**
      * Create an horizontal bargraph box.
@@ -533,7 +570,7 @@ extern "C"
      *
      * @return the horizontal bargraph box.
      */
-    Box CboxHBargraph(const char* label, Box min, Box max);
+    LIBFAUST_API Box CboxHBargraph(const char* label, Box min, Box max);
     
     /**
      * Create a horizontal bargraph box.
@@ -543,9 +580,9 @@ extern "C"
      * @param max - the max box, a constant numerical expression (see [1])
      * @param x - the input box
      *
-     * @return the vertical horizontal box.
+     * @return the horizontal bargraph box.
      */
-    Box CboxHBargraphAux(const char* label, Box min, Box max, Box x);
+    LIBFAUST_API Box CboxHBargraphAux(const char* label, Box min, Box max, Box x);
     
     /**
      * Create an attach box.
@@ -556,31 +593,111 @@ extern "C"
      *
      * @return the attach box.
      */
-    Box CboxAttach();
+    LIBFAUST_API Box CboxAttach();
     
     /**
      * Create an attach box.
      *
      * The attach primitive takes two input box and produces one output box
      * which is a copy of the first input. The role of attach is to force
-     * its second input signal to be compiled with the first one.
+     * its second input box to be compiled with the first one.
      *
      * @param s1 - the first box
      * @param s2 - the second box
      *
-     * @return the attach signal.
+     * @return the attach box.
      */
-    Box CboxAttachAux(Box s1, Box s2);
+    LIBFAUST_API Box CboxAttachAux(Box b1, Box b2);
+
+    LIBFAUST_API bool CisBoxAbstr(Box t, Box* x, Box* y);
+    LIBFAUST_API bool CisBoxAccess(Box t, Box* exp, Box* id);
+    LIBFAUST_API bool CisBoxAppl(Box t, Box* x, Box* y);
+    LIBFAUST_API bool CisBoxButton(Box b, Box* lbl);
+    LIBFAUST_API bool CisBoxCase(Box b, Box* rules);
+    LIBFAUST_API bool CisBoxCheckbox(Box b, Box* lbl);
+    LIBFAUST_API bool CisBoxComponent(Box b, Box* filename);
+    LIBFAUST_API bool CisBoxCut(Box t);
+    LIBFAUST_API bool CisBoxEnvironment(Box b);
+    LIBFAUST_API bool CisBoxError(Box t);
+    LIBFAUST_API bool CisBoxFConst(Box b, Box* type, Box* name, Box* file);
+    LIBFAUST_API bool CisBoxFFun(Box b, Box* ff);
+    LIBFAUST_API bool CisBoxFVar(Box b, Box* type, Box* name, Box* file);
+    LIBFAUST_API bool CisBoxHBargraph(Box b, Box* lbl, Box* min, Box* max);
+    LIBFAUST_API bool CisBoxHGroup(Box b, Box* lbl, Box* x);
+    LIBFAUST_API bool CisBoxHSlider(Box b, Box* lbl, Box* cur, Box* min, Box* max, Box* step);
+    LIBFAUST_API bool CisBoxIdent(Box t, const char** str);
+    LIBFAUST_API bool CisBoxInputs(Box t, Box* x);
+    LIBFAUST_API bool CisBoxInt(Box t, int* i);
+    LIBFAUST_API bool CisBoxIPar(Box t, Box* x, Box* y, Box* z);
+    LIBFAUST_API bool CisBoxIProd(Box t, Box* x, Box* y, Box* z);
+    LIBFAUST_API bool CisBoxISeq(Box t, Box* x, Box* y, Box* z);
+    LIBFAUST_API bool CisBoxISum(Box t, Box* x, Box* y, Box* z);
+    LIBFAUST_API bool CisBoxLibrary(Box b, Box* filename);
+    LIBFAUST_API bool CisBoxMerge(Box t, Box* x, Box* y);
+    LIBFAUST_API bool CisBoxMetadata(Box b, Box* exp, Box* mdlist);
+    LIBFAUST_API bool CisBoxNumEntry(Box b, Box* lbl, Box* cur, Box* min, Box* max, Box* step);
+    LIBFAUST_API bool CisBoxOutputs(Box t, Box* x);
+    LIBFAUST_API bool CisBoxPar(Box t, Box* x, Box* y);
+    LIBFAUST_API bool CisBoxPatternMatcher(Box b);
+    LIBFAUST_API bool CisBoxPatternVar(Box b, Box* id);
+    LIBFAUST_API bool CisBoxPrim0(Box b);
+    LIBFAUST_API bool CisBoxPrim1(Box b);
+    LIBFAUST_API bool CisBoxPrim2(Box b);
+    LIBFAUST_API bool CisBoxPrim3(Box b);
+    LIBFAUST_API bool CisBoxPrim4(Box b);
+    LIBFAUST_API bool CisBoxPrim5(Box b);
+    LIBFAUST_API bool CisBoxReal(Box t, double* r);
+    LIBFAUST_API bool CisBoxRec(Box t, Box* x, Box* y);
+    LIBFAUST_API bool CisBoxRoute(Box b, Box* n, Box* m, Box* r);
+    LIBFAUST_API bool CisBoxSeq(Box t, Box* x, Box* y);
+    LIBFAUST_API bool CisBoxSlot(Box t, int* id);
+    LIBFAUST_API bool CisBoxSoundfile(Box b, Box* label, Box* chan);
+    LIBFAUST_API bool CisBoxSplit(Box t, Box* x, Box* y);
+    LIBFAUST_API bool CisBoxSymbolic(Box t, Box* slot, Box* body);
+    LIBFAUST_API bool CisBoxTGroup(Box b, Box* lbl, Box* x);
+    LIBFAUST_API bool CisBoxVBargraph(Box b, Box* lbl, Box* min, Box* max);
+    LIBFAUST_API bool CisBoxVGroup(Box b, Box* lbl, Box* x);
+    LIBFAUST_API bool CisBoxVSlider(Box b, Box* lbl, Box* cur, Box* min, Box* max, Box* step);
+    LIBFAUST_API bool CisBoxWaveform(Box b);
+    LIBFAUST_API bool CisBoxWire(Box t);
+    LIBFAUST_API bool CisBoxWithLocalDef(Box t, Box* body, Box* ldef);
+
+    /**
+     * Compile a DSP source code as a string in a flattened box
+     *
+     * @param name_app - the name of the Faust program
+     * @param dsp_content - the Faust program as a string
+     * @param argc - the number of parameters in argv array
+     * @param argv - the array of parameters
+     * @param inputs - the place to return the number of inputs of the resulting box
+     * @param outputs - the place to return the number of outputs of the resulting box
+     * @param error_msg - the error string to be filled
+     *
+     * @return a flattened box on success, otherwise a null pointer.
+     */
+    LIBFAUST_API Box CDSPToBoxes(const char* name_appp, const char* dsp_content, int argc, const char* argv[], int* inputs, int* outputs, char* error_msg);
     
     /**
-     * Compile a box expression in a null terminated array of signals.
+     * Return the number of inputs and outputs of a box
+     *
+     * @param box - the box we want to know the number of inputs and outputs
+     * @param inputs - the place to return the number of inputs
+     * @param outputs - the place to return the number of outputs
+     *
+     * @return true if type is defined, false if undefined.
+     */
+    LIBFAUST_API bool CgetBoxType(Box box, int* inputs, int* outputs);
+
+    /**
+     * Compile a box expression in a null terminated array of signals in normal form
+     * (see CsimplifyToNormalForm in libfaust-signal-c.h)
      *
      * @param box - the box expression
-     * @param error_msg - the error string to be filled
+     * @param error_msg - the error string to be filled, has to be 4096 characters long
      *
      * @return a null terminated array of signals on success (to be deleted by the caller using freeCMemory), otherwise a nullptr.
      */
-    Signal* CboxesToSignals(Box box, char* error_msg);
+    LIBFAUST_API Signal* CboxesToSignals(Box box, char* error_msg);
     
     /*
      [1] Constant numerical expression : see https://faustdoc.grame.fr/manual/syntax/#constant-numerical-expressions
@@ -596,5 +713,3 @@ extern "C"
  */
 
 #endif
-
-
