@@ -40,7 +40,8 @@ architecture section is not modified.
 #include "faust/gui/meta.h"
 
 /*!
- \addtogroup llvmcpp C++ interface for compiling Faust code with the LLVM backend. Note that the API is not thread safe: use 'startMTDSPFactories/stopMTDSPFactories' to use it in a multi-thread context.
+ \addtogroup llvmcpp C++ interface for compiling Faust code with the LLVM backend.
+ Note that the API is not thread safe: use 'startMTDSPFactories/stopMTDSPFactories' to use it in a multi-thread context.
  @{
  */
  
@@ -49,12 +50,12 @@ architecture section is not modified.
  * 
  * @return the library version as a static string.
  */
-extern "C" const char* getCLibFaustVersion();
+extern "C" LIBFAUST_API const char* getCLibFaustVersion();
 
 /**
  * DSP instance class with methods.
  */
-class llvm_dsp : public dsp {
+class LIBFAUST_API llvm_dsp : public dsp {
     
     private:
     
@@ -93,7 +94,7 @@ class llvm_dsp : public dsp {
  * DSP factory class.
  */
 
-class llvm_dsp_factory : public dsp_factory {
+class LIBFAUST_API llvm_dsp_factory : public dsp_factory {
 
      public:
     
@@ -141,7 +142,7 @@ class llvm_dsp_factory : public dsp_factory {
  *
  * @return the target as a string.
  */
-std::string getDSPMachineTarget();
+LIBFAUST_API std::string getDSPMachineTarget();
 
 /**
  * Get the Faust DSP factory associated with a given SHA key (created from the 'expanded' DSP source), 
@@ -152,7 +153,7 @@ std::string getDSPMachineTarget();
  *
  * @return a DSP factory if one is associated with the SHA key, otherwise a null pointer.
  */
-llvm_dsp_factory* getDSPFactoryFromSHAKey(const std::string& sha_key);
+LIBFAUST_API llvm_dsp_factory* getDSPFactoryFromSHAKey(const std::string& sha_key);
 
 /**
  * Create a Faust DSP factory from a DSP source code as a file. Note that the library keeps an internal cache of all 
@@ -172,11 +173,11 @@ llvm_dsp_factory* getDSPFactoryFromSHAKey(const std::string& sha_key);
  *
  * @return a DSP factory on success, otherwise a null pointer.
  */ 
-llvm_dsp_factory* createDSPFactoryFromFile(const std::string& filename, 
-                                           int argc, const char* argv[], 
-                                           const std::string& target, 
-                                           std::string& error_msg,
-                                           int opt_level = -1);
+LIBFAUST_API llvm_dsp_factory* createDSPFactoryFromFile(const std::string& filename,
+                                                        int argc, const char* argv[],
+                                                        const std::string& target,
+                                                        std::string& error_msg,
+                                                        int opt_level = -1);
 
 /**
  * Create a Faust DSP factory from a DSP source code as a string. Note that the library keeps an internal cache of all 
@@ -197,12 +198,12 @@ llvm_dsp_factory* createDSPFactoryFromFile(const std::string& filename,
  *
  * @return a DSP factory on success, otherwise a null pointer.
  */ 
-llvm_dsp_factory* createDSPFactoryFromString(const std::string& name_app,
-                                             const std::string& dsp_content,
-                                             int argc, const char* argv[], 
-                                             const std::string& target, 
-                                             std::string& error_msg,
-                                             int opt_level = -1);
+LIBFAUST_API llvm_dsp_factory* createDSPFactoryFromString(const std::string& name_app,
+                                                        const std::string& dsp_content,
+                                                        int argc, const char* argv[],
+                                                        const std::string& target,
+                                                        std::string& error_msg,
+                                                        int opt_level = -1);
 
 /**
  * Create a Faust DSP factory from a vector of output signals.
@@ -221,11 +222,11 @@ llvm_dsp_factory* createDSPFactoryFromString(const std::string& name_app,
  *
  * @return a DSP factory on success, otherwise a null pointer.
  */
-llvm_dsp_factory* createDSPFactoryFromSignals(const std::string& name_app, tvec signals_vec,
-                                              int argc, const char* argv[],
-                                              const std::string& target,
-                                              std::string& error_msg,
-                                              int opt_level = -1);
+LIBFAUST_API llvm_dsp_factory* createDSPFactoryFromSignals(const std::string& name_app, tvec signals_vec,
+                                                        int argc, const char* argv[],
+                                                        const std::string& target,
+                                                        std::string& error_msg,
+                                                        int opt_level = -1);
 
 /**
  * Create a Faust DSP factory from a box expression.
@@ -244,11 +245,11 @@ llvm_dsp_factory* createDSPFactoryFromSignals(const std::string& name_app, tvec
  *
  * @return a DSP factory on success, otherwise a null pointer.
  */
-llvm_dsp_factory* createDSPFactoryFromBoxes(const std::string& name_app, Box box,
-                                            int argc, const char* argv[],
-                                            const std::string& target,
-                                            std::string& error_msg,
-                                            int opt_level = -1);
+LIBFAUST_API llvm_dsp_factory* createDSPFactoryFromBoxes(const std::string& name_app, Box box,
+                                                        int argc, const char* argv[],
+                                                        const std::string& target,
+                                                        std::string& error_msg,
+                                                        int opt_level = -1);
 
 /**
  * Delete a Faust DSP factory, that is decrements it's reference counter, possibly really deleting the internal pointer. 
@@ -259,7 +260,7 @@ llvm_dsp_factory* createDSPFactoryFromBoxes(const std::string& name_app, Box box
  *
  * @return true if the factory internal pointer was really deleted, and false if only 'decremented'.
  */                                 
-bool deleteDSPFactory(llvm_dsp_factory* factory);
+LIBFAUST_API bool deleteDSPFactory(llvm_dsp_factory* factory);
 
 /**
  * Get the Faust DSP factory list of library dependancies.
@@ -274,29 +275,27 @@ DEPRECATED(std::vector<std::string> getDSPFactoryLibraryList(llvm_dsp_factory* f
 
 /**
  * Delete all Faust DSP factories kept in the library cache. Beware: all kept factory and DSP pointers (in local variables...) thus become invalid.
- * 
  */                                 
-void deleteAllDSPFactories();
+LIBFAUST_API void deleteAllDSPFactories();
 
 /**
  * Return Faust DSP factories of the library cache as a vector of their SHA keys.
  * 
  * @return the Faust DSP factories.
  */                                 
-std::vector<std::string> getAllDSPFactories();
+LIBFAUST_API std::vector<std::string> getAllDSPFactories();
 
 /**
  * Start multi-thread access mode (since by default the library is not 'multi-thread' safe).
  * 
  * @return true if 'multi-thread' safe access is started.
  */ 
-extern "C" bool startMTDSPFactories();
+extern "C" LIBFAUST_API bool startMTDSPFactories();
 
 /**
  * Stop multi-thread access mode.
- * 
  */ 
-extern "C" void stopMTDSPFactories();
+extern "C" LIBFAUST_API void stopMTDSPFactories();
 
 /**
  * Create a Faust DSP factory from a base64 encoded LLVM bitcode string. Note that the library keeps an internal cache of all 
@@ -314,7 +313,7 @@ extern "C" void stopMTDSPFactories();
  *
  * @return the DSP factory on success, otherwise a null pointer.
  */
-llvm_dsp_factory* readDSPFactoryFromBitcode(const std::string& bit_code, const std::string& target, std::string& error_msg, int opt_level = -1);
+LIBFAUST_API llvm_dsp_factory* readDSPFactoryFromBitcode(const std::string& bit_code, const std::string& target, std::string& error_msg, int opt_level = -1);
 
 /**
  * Write a Faust DSP factory into a base64 encoded LLVM bitcode string.
@@ -323,7 +322,7 @@ llvm_dsp_factory* readDSPFactoryFromBitcode(const std::string& bit_code, const s
  *
  * @return the LLVM bitcode as a string.
  */
-std::string writeDSPFactoryToBitcode(llvm_dsp_factory* factory);
+LIBFAUST_API std::string writeDSPFactoryToBitcode(llvm_dsp_factory* factory);
 
 /**
  * Create a Faust DSP factory from a LLVM bitcode file. Note that the library keeps an internal cache of all 
@@ -342,7 +341,7 @@ std::string writeDSPFactoryToBitcode(llvm_dsp_factory* factory);
  * 
  * @return the DSP factory on success, otherwise a null pointer.
  */
-llvm_dsp_factory* readDSPFactoryFromBitcodeFile(const std::string& bit_code_path, const std::string& target, std::string& error_msg, int opt_level = -1);
+LIBFAUST_API llvm_dsp_factory* readDSPFactoryFromBitcodeFile(const std::string& bit_code_path, const std::string& target, std::string& error_msg, int opt_level = -1);
 
 /**
  * Write a Faust DSP factory into a LLVM bitcode file.
@@ -352,7 +351,7 @@ llvm_dsp_factory* readDSPFactoryFromBitcodeFile(const std::string& bit_code_path
  *
  * @return true on success, false on failure.
  */
-bool writeDSPFactoryToBitcodeFile(llvm_dsp_factory* factory, const std::string& bit_code_path);
+LIBFAUST_API bool writeDSPFactoryToBitcodeFile(llvm_dsp_factory* factory, const std::string& bit_code_path);
 
 /**
  * Create a Faust DSP factory from a LLVM IR (textual) string. Note that the library keeps an internal cache of all 
@@ -371,7 +370,7 @@ bool writeDSPFactoryToBitcodeFile(llvm_dsp_factory* factory, const std::string&
  *
  * @return the DSP factory on success, otherwise a null pointer.
  */
-llvm_dsp_factory* readDSPFactoryFromIR(const std::string& ir_code, const std::string& target, std::string& error_msg, int opt_level = -1);
+LIBFAUST_API llvm_dsp_factory* readDSPFactoryFromIR(const std::string& ir_code, const std::string& target, std::string& error_msg, int opt_level = -1);
 
 /**
  * Write a Faust DSP factory into a LLVM IR (textual) string.
@@ -380,7 +379,7 @@ llvm_dsp_factory* readDSPFactoryFromIR(const std::string& ir_code, const std::st
  *
  * @return the LLVM IR (textual) as a string.
  */
-std::string writeDSPFactoryToIR(llvm_dsp_factory* factory);
+LIBFAUST_API std::string writeDSPFactoryToIR(llvm_dsp_factory* factory);
 
 /**
  * Create a Faust DSP factory from a LLVM IR (textual) file. Note that the library keeps an internal cache of all 
@@ -399,7 +398,7 @@ std::string writeDSPFactoryToIR(llvm_dsp_factory* factory);
  *
  * @return the DSP factory on success, otherwise a null pointer.
  */
-llvm_dsp_factory* readDSPFactoryFromIRFile(const std::string& ir_code_path, const std::string& target, std::string& error_msg, int opt_level = -1);
+LIBFAUST_API llvm_dsp_factory* readDSPFactoryFromIRFile(const std::string& ir_code_path, const std::string& target, std::string& error_msg, int opt_level = -1);
 
 /**
  * Write a Faust DSP factory into a LLVM IR (textual) file.
@@ -409,7 +408,7 @@ llvm_dsp_factory* readDSPFactoryFromIRFile(const std::string& ir_code_path, cons
  *
  * @return true on success, false on failure.
  */
-bool writeDSPFactoryToIRFile(llvm_dsp_factory* factory, const std::string& ir_code_path);
+LIBFAUST_API bool writeDSPFactoryToIRFile(llvm_dsp_factory* factory, const std::string& ir_code_path);
 
 /**
  * Create a Faust DSP factory from a base64 encoded machine code string. Note that the library keeps an internal cache of all 
@@ -425,7 +424,7 @@ bool writeDSPFactoryToIRFile(llvm_dsp_factory* factory, const std::string& ir_co
  *
  * @return the DSP factory on success, otherwise a null pointer.
  */
-llvm_dsp_factory* readDSPFactoryFromMachine(const std::string& machine_code, const std::string& target, std::string& error_msg);
+LIBFAUST_API llvm_dsp_factory* readDSPFactoryFromMachine(const std::string& machine_code, const std::string& target, std::string& error_msg);
 
 /**
  * Write a Faust DSP factory into a base64 encoded machine code string.
@@ -437,7 +436,7 @@ llvm_dsp_factory* readDSPFactoryFromMachine(const std::string& machine_code, con
  *
  * @return the machine code as a string.
  */
-std::string writeDSPFactoryToMachine(llvm_dsp_factory* factory, const std::string& target);
+LIBFAUST_API std::string writeDSPFactoryToMachine(llvm_dsp_factory* factory, const std::string& target);
 
 /**
  * Create a Faust DSP factory from a machine code file. Note that the library keeps an internal cache of all 
@@ -453,7 +452,7 @@ std::string writeDSPFactoryToMachine(llvm_dsp_factory* factory, const std::strin
  *
  * @return the DSP factory on success, otherwise a null pointer.
  */
-llvm_dsp_factory* readDSPFactoryFromMachineFile(const std::string& machine_code_path, const std::string& target, std::string& error_msg);
+LIBFAUST_API llvm_dsp_factory* readDSPFactoryFromMachineFile(const std::string& machine_code_path, const std::string& target, std::string& error_msg);
 
 /**
  * Write a Faust DSP factory into a machine code file.
@@ -466,7 +465,7 @@ llvm_dsp_factory* readDSPFactoryFromMachineFile(const std::string& machine_code_
  *
  * @return true on success, false on failure.
  */
-bool writeDSPFactoryToMachineFile(llvm_dsp_factory* factory, const std::string& machine_code_path, const std::string& target);
+LIBFAUST_API bool writeDSPFactoryToMachineFile(llvm_dsp_factory* factory, const std::string& machine_code_path, const std::string& target);
 
 /**
  * Write a Faust DSP factory into an object code file.
@@ -479,7 +478,7 @@ bool writeDSPFactoryToMachineFile(llvm_dsp_factory* factory, const std::string&
  *
  * @return true on success, false on failure.
  */
-bool writeDSPFactoryToObjectcodeFile(llvm_dsp_factory* factory, const std::string& object_code_path, const std::string& target);
+LIBFAUST_API bool writeDSPFactoryToObjectcodeFile(llvm_dsp_factory* factory, const std::string& object_code_path, const std::string& target);
 
 /**
  * Call global declarations with the given meta object.
@@ -509,6 +508,13 @@ DEPRECATED(llvm_dsp* createDSPInstance(llvm_dsp_factory* factory));
  */ 
 DEPRECATED(void deleteDSPInstance(llvm_dsp* dsp));
 
+/**
+ * Register a custom foreign function that will be exported by the host binary running the DSP code.
+ *
+ * @param function_name - the function name to be available
+ */
+LIBFAUST_API void registerForeignFunction(const std::string& function_name);
+
 /*!
  @}
  */
